@@ -149,8 +149,8 @@ class Confluence(AtlassianRestAPI):
         else:
             try:
                 return (self.get(url, params=params) or {}).get('results')[0]
-            except IndexError as e:
-                log.error("Can't find {title} page on the {url}!".format(title=title, url=self.url))
+            except (IndexError, TypeError) as e:
+                log.error("Can't find '{title}' page on the {url}!".format(title=title, url=self.url))
                 log.debug(e)
                 return None
 
@@ -249,8 +249,8 @@ class Confluence(AtlassianRestAPI):
         url = 'rest/api/content/search'
         params = {}
         if label:
-            params['cql'] = 'type={type} AND label={label}'.format(type='page',
-                                                                   label=label)
+            params['cql'] = 'type={type} AND label="{label}"'.format(type='page',
+                                                                     label=label)
         if start:
             params['start'] = start
         if limit:
@@ -338,6 +338,11 @@ class Confluence(AtlassianRestAPI):
         return (self.get(url, params=params) or {}).get('results')
 
     def get_all_restictions_for_content(self, content_id):
+        """keep typo method"""
+        log.warning("Please, be informed that is deprecated as typo naming")
+        return self.get_all_restrictions_for_content(content_id=content_id)
+
+    def get_all_restrictions_for_content(self, content_id):
         """
         Returns info about all restrictions by operation.
         :param content_id:
@@ -561,6 +566,13 @@ class Confluence(AtlassianRestAPI):
         log.info("Kept versions {} for {}".format(keep_last_versions, attachment.get('title')))
 
     def get_attachment_history(self, attachment_id, limit=200, start=0):
+        """
+        Get attachment history
+        :param attachment_id
+        :param limit
+        :param start
+        :return
+        """
         params = {'limit': limit, 'start': start}
         url = 'rest/experimental/content/{}/version'.format(attachment_id)
         return (self.get(url, params=params) or {}).get("results")
@@ -623,6 +635,12 @@ class Confluence(AtlassianRestAPI):
         return self.history(content_id)
 
     def get_content_history_by_version_number(self, content_id, version_number):
+        """
+        Get content history by version number
+        :param content_id:
+        :param version_number:
+        :return:
+        """
         url = 'rest/experimental/content/{0}/version/{1}'.format(content_id, version_number)
         return self.get(url)
 
@@ -686,24 +704,34 @@ class Confluence(AtlassianRestAPI):
             return result.get('_links').get('base') + result.get('_links').get('tinyui')
         return ""
 
-    def is_page_content_is_already_updated(self, page_id, body):
+    def is_page_content_is_already_updated(self, page_id, body, title=None):
         """
         Compare content and check is already updated or not
         :param page_id: Content ID for retrieve storage value
         :param body: Body for compare it
+        :param title: Title to compare
         :return: True if the same
         """
         confluence_content = (((self.get_page_by_id(page_id, expand='body.storage') or {})
                                .get('body') or {})
-                              .get('storage') or {}).get('value')
-        if confluence_content:
-            # @todo move into utils
-            confluence_content = utils.symbol_normalizer(confluence_content)
+                              .get('storage') or {})
 
-        log.debug('Old Content: """{body}"""'.format(body=confluence_content))
+        if title:
+            current_title = confluence_content.get('title', None)
+            if title != current_title:
+                log.info('Title of {page_id} is different'.format(page_id=page_id))
+                return False
+
+        confluence_body_content = confluence_content.get('value')
+
+        if confluence_body_content:
+            # @todo move into utils
+            confluence_body_content = utils.symbol_normalizer(confluence_body_content)
+
+        log.debug('Old Content: """{body}"""'.format(body=confluence_body_content))
         log.debug('New Content: """{body}"""'.format(body=body))
 
-        if confluence_content == body:
+        if confluence_body_content == body:
             log.warning('Content of {page_id} is exactly the same'.format(page_id=page_id))
             return True
         else:
@@ -733,10 +761,15 @@ class Confluence(AtlassianRestAPI):
         """
         log.info('Updating {type} "{title}"'.format(title=title, type=type))
 
-        if self.is_page_content_is_already_updated(page_id, body):
+        if self.is_page_content_is_already_updated(page_id, body, title):
             return self.get_page_by_id(page_id)
         else:
-            version = self.history(page_id)['lastUpdated']['number'] + 1
+            try:
+                version = self.history(page_id)['lastUpdated']['number'] + 1
+            except (IndexError, TypeError) as e:
+                log.error("Can't find '{title}' {type}!".format(title=title, type=type))
+                log.debug(e)
+                return None
 
             data = {
                 'id': page_id,
@@ -768,7 +801,7 @@ class Confluence(AtlassianRestAPI):
         """
         log.info('Updating {type} "{title}"'.format(title=title, type=type))
 
-        if self.is_page_content_is_already_updated(page_id, append_body):
+        if self.is_page_content_is_already_updated(page_id, append_body, title):
             return self.get_page_by_id(page_id)
         else:
             version = self.history(page_id)['lastUpdated']['number'] + 1
