@@ -325,7 +325,7 @@ class Jira(AtlassianRestAPI):
         Add a user to an application
         :param username: The username of the user to add.
         :param application_key: The application key of the application
-        :return: True if the user was added to the application, else False        
+        :return: True if the user was added to the application, else False
         :see: https://docs.atlassian.com/software/jira/docs/api/REST/7.5.3/#api/2/user-addUserToApplication
         """
         params = {
@@ -1759,6 +1759,16 @@ class Jira(AtlassianRestAPI):
         url = 'rest/tempo-accounts/1/account/{id}/'.format(id=account_id)
         return self.delete(url)
 
+    def tempo_account_get_rate_table_by_account_id(self, account_id):
+        """
+        Returns a rate table for the specified account.
+        :param account_id: the account id.
+        :return:
+        """
+        params = {'scopeType': "ACCOUNT", 'scopeId': account_id}
+        url = 'rest/tempo-accounts/1/ratetable'
+        return self.get(url, params=params)
+
     def tempo_account_get_all_account_by_customer_id(self, customer_id):
         """
         Get un-archived Accounts by customer. The Caller must have the Browse Account permission for the Account.
@@ -2068,7 +2078,7 @@ class Jira(AtlassianRestAPI):
         """
         Add team member
         :param team_id:
-        :param member_key:
+        :param member_key: user_name or user_key of Jira
         :return:
         """
         data = {"member": {"key": str(member_key), "type": "USER"},
